==> contentsquare-1.0.1.tar.gz: example/simple_app/lib/src/screens/cases/cases_screen.dart <==
import 'package:flutter/material.dart';

import '../../utils/navigate_and_monitor.dart';
import 'widgets/recyclable/custom_scroll_view_screen.dart';
import 'widgets/recyclable/grid_view_screen.dart';
import 'widgets/recyclable/list_view_screen.dart';
import 'widgets/recyclable/sliver_grid_screen.dart';
import 'widgets/recyclable/sliver_list_screen.dart';

class CasesScreen extends StatelessWidget {
  const CasesScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(top: 30.0),
      child: Column(
        children: [
          Padding(
            padding: EdgeInsets.symmetric(horizontal: 16),
            child: Text(
              'Select an item to launch the corresponding screen',
              style: Theme.of(context).textTheme.headline6,
            ),
          ),
          SizedBox(height: 20),
          ListTile(
            title: Text('ListView'),
            onTap: () => navigateAndMonitor(context, ListViewScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('SilverList'),
            onTap: () => navigateAndMonitor(context, SliverListScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('GridView'),
            onTap: () => navigateAndMonitor(context, GridViewScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('SilverGrid'),
            onTap: () => navigateAndMonitor(context, SliverGridScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('CustomScrollView'),
            onTap: () => navigateAndMonitor(context, CustomScrollViewScreen()),
          ),
          SizedBox(height: 10),
        ],
      ),
    );
  }
}

==> contentsquare-2.3.0.tar.gz: example/simple_app/lib/src/screens/cases/cases_screen.dart <==
import 'package:flutter/material.dart';

import '../../utils/navigate_and_monitor.dart';
import 'widgets/recyclable/custom_scroll_view_screen.dart';
import 'widgets/recyclable/grid_view_screen.dart';
import 'widgets/recyclable/list_view_screen.dart';
import 'widgets/recyclable/sliver_grid_screen.dart';
import 'widgets/recyclable/sliver_list_screen.dart';

class CasesScreen extends StatelessWidget {
  const CasesScreen({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: const EdgeInsets.only(top: 30.0),
      child: Column(
        children: [
          Padding(
            padding: EdgeInsets.symmetric(horizontal: 16),
            child: Text(
              'Select an item to launch the corresponding screen',
              style: Theme.of(context).textTheme.titleLarge,
            ),
          ),
          SizedBox(height: 20),
          ListTile(
            title: Text('ListView'),
            onTap: () => navigateAndMonitor(context, ListViewScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('SilverList'),
            onTap: () => navigateAndMonitor(context, SliverListScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('GridView'),
            onTap: () => navigateAndMonitor(context, GridViewScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('SilverGrid'),
            onTap: () => navigateAndMonitor(context, SliverGridScreen()),
          ),
          SizedBox(height: 10),
          ListTile(
            title: Text('CustomScrollView'),
            onTap: () => navigateAndMonitor(context, CustomScrollViewScreen()),
          ),
          SizedBox(height: 10),
        ],
      ),
    );
  }
}
